| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Mu.GRpc.Client.Optics
Description
For further information over initialization of the connection, consult the http2-client-grpc docs.
Synopsis
- data GRpcConnection (s :: Package') (p :: GRpcMessageProtocol)
- initGRpc :: GrpcClientConfig -> Proxy p -> forall s. IO (Either ClientError (GRpcConnection s p))
- data GRpcMessageProtocol
- msgProtoBuf :: Proxy 'MsgProtoBuf
- msgAvro :: Proxy 'MsgAvro
- data GrpcClientConfig
- grpcClientConfigSimple :: HostName -> PortNumber -> UseTlsOrNot -> GrpcClientConfig
- data CompressMode
- data GRpcReply a
- module Optics.Core
Initialization of the gRPC client
data GRpcConnection (s :: Package') (p :: GRpcMessageProtocol) Source #
Represents a connection to the service s.
Instances
| (pkg ~ 'Package ('Just pkgName) '[service], service ~ 'Service serviceName anns methods, SearchMethodOptic p methods m t, KnownName serviceName, KnownName pkgName, KnownName m, MkRPC p) => LabelOptic m A_Getter (GRpcConnection pkg p) (GRpcConnection pkg p) t t Source # | |
Defined in Mu.GRpc.Client.Optics Methods labelOptic :: Optic A_Getter NoIx (GRpcConnection pkg p) (GRpcConnection pkg p) t t # | |
Arguments
| :: GrpcClientConfig | gRPC configuration |
| -> Proxy p | |
| -> forall s. IO (Either ClientError (GRpcConnection s p)) |
Initializes a connection to a gRPC server. Usually the service you are connecting to is inferred from the usage later on. However, it can also be made explicit by using
initGRpc config msgProtoBuf @Service
data GRpcMessageProtocol #
Constructors
| MsgProtoBuf | |
| MsgAvro |
Instances
| Eq GRpcMessageProtocol | |
Defined in Mu.GRpc.Bridge Methods (==) :: GRpcMessageProtocol -> GRpcMessageProtocol -> Bool # (/=) :: GRpcMessageProtocol -> GRpcMessageProtocol -> Bool # | |
| Show GRpcMessageProtocol | |
Defined in Mu.GRpc.Bridge Methods showsPrec :: Int -> GRpcMessageProtocol -> ShowS # show :: GRpcMessageProtocol -> String # showList :: [GRpcMessageProtocol] -> ShowS # | |
msgProtoBuf :: Proxy 'MsgProtoBuf #
data GrpcClientConfig #
Configuration to setup a GrpcClient.
grpcClientConfigSimple :: HostName -> PortNumber -> UseTlsOrNot -> GrpcClientConfig #
Request arguments and responses
data CompressMode #
Constructors
| GRpcTooMuchConcurrency TooMuchConcurrency | |
| GRpcErrorCode ErrorCode | |
| GRpcErrorString String | |
| GRpcClientError ClientError | |
| GRpcOk a |
Re-exported for convenience
module Optics.Core